Add updated debug-info test trace

Some event and field names were changed in the final LTTng 2.8
release. Add a new trace with updated names. This supersedes
the "debug-info-test-app2" trace (which will remain here but
be marked @Deprecated for now).

See https://lists.lttng.org/pipermail/lttng-dev/2016-April/025764.html

Bump version to 1.4.0.

Signed-off-by: Alexandre Montplaisir <alexmonthy@efficios.com>
diff --git a/ctf/pom.xml b/ctf/pom.xml
index e670f2f..ad4301d 100644
--- a/ctf/pom.xml
+++ b/ctf/pom.xml
@@ -15,7 +15,7 @@
   <parent>
     <groupId>org.eclipse.tracecompass.testtraces</groupId>
     <artifactId>tracecompass-test-traces-parent</artifactId>
-    <version>1.3.0</version>
+    <version>1.4.0</version>
   </parent>
 
   <artifactId>tracecompass-test-traces-ctf</artifactId>
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_0 b/ctf/src/main/resources/debuginfo-test-app3/channel0_0
new file mode 100644
index 0000000..6447ab0
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_0
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_1 b/ctf/src/main/resources/debuginfo-test-app3/channel0_1
new file mode 100644
index 0000000..e848291
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_1
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_2 b/ctf/src/main/resources/debuginfo-test-app3/channel0_2
new file mode 100644
index 0000000..99f07f3
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_2
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_3 b/ctf/src/main/resources/debuginfo-test-app3/channel0_3
new file mode 100644
index 0000000..6d6ddad
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_3
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_4 b/ctf/src/main/resources/debuginfo-test-app3/channel0_4
new file mode 100644
index 0000000..f1a97a8
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_4
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_5 b/ctf/src/main/resources/debuginfo-test-app3/channel0_5
new file mode 100644
index 0000000..e8fe14e
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_5
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_6 b/ctf/src/main/resources/debuginfo-test-app3/channel0_6
new file mode 100644
index 0000000..6d7d96b
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_6
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/channel0_7 b/ctf/src/main/resources/debuginfo-test-app3/channel0_7
new file mode 100644
index 0000000..20527e7
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/channel0_7
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_0.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_0.idx
new file mode 100644
index 0000000..0828da2
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_0.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_1.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_1.idx
new file mode 100644
index 0000000..460b457
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_1.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_2.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_2.idx
new file mode 100644
index 0000000..817044d
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_2.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_3.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_3.idx
new file mode 100644
index 0000000..3cd752c
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_3.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_4.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_4.idx
new file mode 100644
index 0000000..8a2d01b
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_4.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_5.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_5.idx
new file mode 100644
index 0000000..d808a40
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_5.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_6.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_6.idx
new file mode 100644
index 0000000..e02a029
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_6.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/index/channel0_7.idx b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_7.idx
new file mode 100644
index 0000000..adecac1
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/index/channel0_7.idx
Binary files differ
diff --git a/ctf/src/main/resources/debuginfo-test-app3/metadata b/ctf/src/main/resources/debuginfo-test-app3/metadata
new file mode 100644
index 0000000..b59a9e8
--- /dev/null
+++ b/ctf/src/main/resources/debuginfo-test-app3/metadata
Binary files differ
diff --git a/pom.xml b/pom.xml
index ebf3758..2084b08 100644
--- a/pom.xml
+++ b/pom.xml
@@ -18,7 +18,7 @@
 
   <groupId>org.eclipse.tracecompass.testtraces</groupId>
   <artifactId>tracecompass-test-traces-parent</artifactId>
-  <version>1.3.0</version>
+  <version>1.4.0</version>
   <packaging>pom</packaging>
 
   <properties>
diff --git a/update-site/pom.xml b/update-site/pom.xml
index 41df0b4..fd9a661 100644
--- a/update-site/pom.xml
+++ b/update-site/pom.xml
@@ -16,7 +16,7 @@
   <parent>
     <groupId>org.eclipse.tracecompass.testtraces</groupId>
     <artifactId>tracecompass-test-traces-parent</artifactId>
-    <version>1.3.0</version>
+    <version>1.4.0</version>
   </parent>
 
   <artifactId>tracecompass-test-traces-update-site</artifactId>
diff --git a/ctf/src/main/java/org/eclipse/tracecompass/testtraces/ctf/CtfTestTrace.java b/ctf/src/main/java/org/eclipse/tracecompass/testtraces/ctf/CtfTestTrace.java
index 40f3f19..b652318 100644
--- a/ctf/src/main/java/org/eclipse/tracecompass/testtraces/ctf/CtfTestTrace.java
+++ b/ctf/src/main/java/org/eclipse/tracecompass/testtraces/ctf/CtfTestTrace.java
@@ -217,17 +217,34 @@
     /** Set of many traces, do not call getTrace */
     TRACE_EXPERIMENT("/exp", -1, -1),
 
+	/**
+	 * UST Trace with Debug Info information (dev version)
+	 *
+	 * <pre>
+	 * Trace Size: 76 KB (including index/)
+	 * Tracer: lttng-ust 2.8~pre
+	 * Event count: 41
+	 * Trace length: ~1 s
+	 * </pre>
+	 * 
+	 * @deprecated Some event names were changed between the moment this trace
+	 *             was taken, and the final LTTng 2.8 release. Please use the
+	 *             updated {@link #DEBUG_INFO3} trace instead.
+	 */
+    @Deprecated
+    DEBUG_INFO("/debuginfo-test-app2", 41, 1),
+
     /**
-     * UST Trace with Debug Info information
+     * UST Trace with Debug Info information, final LTTng 2.8 version
      *
      * <pre>
      * Trace Size: 76 KB (including index/)
      * Tracer: lttng-ust 2.8~pre
      * Event count: 41
      * Trace length: ~1 s
      * </pre>
      */
-    DEBUG_INFO("/debuginfo-test-app2", 41, 1),
+    DEBUG_INFO3("/debuginfo-test-app3", 291, 2),
 
     /**
      * UST Trace with Memory analysis information
@@ -217,17 +217,34 @@
      *
      * <pre>
-     * Trace Size: 76 KB (including index/)
-     * Tracer: lttng-ust 2.8~pre
-     * Event count: 41
-     * Trace length: ~1 s
+     * Trace Size: 144 KB (including index/)
+     * Tracer: lttng-ust 2.8 RC2
+     * Event count: 291
+     * Trace length: ~2 s
      * </pre>
      */